---
title: <span class="badge object-type-scalar"></span> MillimolesPerLiter
---
# <span class="badge object-type-scalar"></span> MillimolesPerLiter

Concentration: millimoles per litre (mmol/L)

## Definition

```python
# Concentration: millimoles per litre (mmol/L)
MillimolesPerLiter: typing.Literal["conmmolL"] = "conmmolL"
```
